@@ -3,7 +3,7 @@ try:
 except ModuleNotFoundError:
     from normatrix.normatrix.source.file_parser import CFileParse
 
-def check(file: CFileParse) -> (int, int):
+def check(context, file: CFileParse) -> (int, int):
     nb_error = 0
     TAB_NB = 0
     filelines = file.sub_filelines
